@@ -1162,8 +1162,7 @@ response:
 		break;
 	case AVRCP_EVENT_TRACK_CHANGED:
 		id = get_u64(frm);
-		printf("Identifier: 0x%jx (%s)\n", id,
-						id ? "Reserved" : "PLAYING");
+		printf("Identifier: 0x%16" PRIx64 " (%" PRIu64 ")\n", id, id);
 		break;
 	case AVRCP_EVENT_PLAYBACK_POS_CHANGED:
 		interval = get_u32(frm);
@@ -1318,7 +1317,7 @@ response:
 	p_indent(level, frm);
 
 	items = get_u32(frm);
-	printf("Number of Items: 0x%04x (%u)\n", items, items);
+	printf("Number of Items: 0x%08x (%u)\n", items, items);
 
 	p_indent(level, frm);
 
@@ -1824,8 +1823,8 @@ static void avrcp_attribute_entry_list_dump(int level, struct frame *frm,
 
 		p_indent(level, frm);
 
-		len = get_u8(frm);
-		printf("AttributeLength: 0x%02x (%u)\n", len, len);
+		len = get_u16(frm);
+		printf("AttributeLength: 0x%04x (%u)\n", len, len);
 
 		p_indent(level, frm);
 
@@ -2070,8 +2069,8 @@ static void avrcp_get_item_attributes_dump(int level, struct frame *frm,
 
 	p_indent(level, frm);
 
-	count = get_u32(frm);
-	printf("AttributeCount: 0x%04x (%u)", count, count);
+	count = get_u8(frm);
+	printf("AttributeCount: 0x%02x (%u)\n", count, count);
 
 	for (; count > 0; count--) {
 		uint32_t attr;
@@ -2093,8 +2092,8 @@ response:
 
 	p_indent(level, frm);
 
-	count = get_u32(frm);
-	printf("AttributeCount: 0x%04x (%u)", count, count);
+	count = get_u8(frm);
+	printf("AttributeCount: 0x%02x (%u)\n", count, count);
 
 	avrcp_attribute_entry_list_dump(level, frm, count);
 }
